"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Highlight = void 0;
class Highlight {
    /**
     * @param {Element} $element
     * @param {Required<IHighlightSettings>} settings
     */
    constructor($element, settings) {
        this.is_highlighted = false;
        this.interval = null;
        this.timeout = null;
        this.$element = $element;
        this.highlightElements = [
            document.createElement('div'),
            document.createElement('div'),
            document.createElement('div'),
            document.createElement('div'), // bottom
        ];
        this.settings = settings;
        this.add = this.add.bind(this);
        this.remove = this.remove.bind(this);
        this.draw = this.draw.bind(this);
    }
    get isHighlighted() { return this.is_highlighted; }
    add() {
        if (this.is_highlighted)
            return;
        this.is_highlighted = true;
        for (const $el of this.highlightElements) {
            $el.style.display = 'block';
            $el.style.opacity = '1';
            $el.style.visibility = 'visible';
            this.$element.appendChild($el);
        }
        this.draw();
        this.interval = setInterval(this.draw, 250);
        if (this.settings.hideAfter > 0 && this.settings.hideAfter !== Infinity)
            this.timeout = setTimeout(this.remove, this.settings.hideAfter);
    }
    remove() {
        if (!this.is_highlighted)
            return;
        this.is_highlighted = false;
        if (this.interval !== null) {
            clearInterval(this.interval);
            this.interval = null;
        }
        if (this.timeout !== null) {
            clearTimeout(this.timeout);
            this.timeout = null;
        }
        for (const $el of this.highlightElements) {
            $el.style.display = 'none';
            $el.style.opacity = '0';
            $el.style.visibility = 'hidden';
            $el.remove();
        }
    }
    /**
     * @protected
     */
    draw() {
        const targetRect = this.$element.getBoundingClientRect(), pageX = window.pageXOffset, pageY = window.pageYOffset;
        for (const $el of this.highlightElements) {
            $el.style.position = 'fixed';
            $el.style.backgroundColor = this.settings.strokeColor;
        }
        // Left
        this.highlightElements[0].style.width = this.settings.strokeSize + 'px';
        this.highlightElements[0].style.height = targetRect.height + 'px';
        this.highlightElements[0].style.left = (targetRect.x + pageX) + 'px';
        this.highlightElements[0].style.top = (targetRect.y + pageY) + 'px';
        // Right
        this.highlightElements[2].style.width = this.settings.strokeSize + 'px';
        this.highlightElements[2].style.height = targetRect.height + 'px';
        this.highlightElements[2].style.left = (targetRect.x + targetRect.width + pageX) + 'px';
        this.highlightElements[2].style.top = (targetRect.y + pageY) + 'px';
        // Top
        this.highlightElements[1].style.height = this.settings.strokeSize + 'px';
        this.highlightElements[1].style.width = targetRect.width + 'px';
        this.highlightElements[1].style.left = (targetRect.x + pageX) + 'px';
        this.highlightElements[1].style.top = (targetRect.y + pageY) + 'px';
        // Bottom
        this.highlightElements[3].style.height = this.settings.strokeSize + 'px';
        this.highlightElements[3].style.width = targetRect.width + 'px';
        this.highlightElements[3].style.left = (targetRect.x + pageX) + 'px';
        this.highlightElements[3].style.top = (targetRect.y + targetRect.height + pageY) + 'px';
    }
}
exports.Highlight = Highlight;
