import {Highlight} from './Highlight';
import {IHighlightSettings} from './IHighlightSettings';

export class DOMHighlighter{

    protected readonly initialSettings: Required<IHighlightSettings>;

    /**
     * @param {IHighlightSettings} [initialSettings={}]
     */
    public constructor(initialSettings: Partial<IHighlightSettings> = {}){
        this.initialSettings = Object.assign({}, {
            strokeColor: '#ff0000',
            strokeSize: 2,
            hideAfter: 0
        }, initialSettings);
    }

    /**
     * @param {Element} $element
     * @param {Partial<IHighlightSettings>} [settings={}]
     * @return {Highlight}
     */
    public highlight($element: Element, settings: Partial<IHighlightSettings> = {}): Highlight{
        const mergedSettings = Object.assign({}, this.initialSettings, settings);
        const hg = new Highlight($element, mergedSettings);
        hg.add();
        return hg;
    }

}
